FutureValue

Struct FutureValue 

pub struct FutureValue { /* private fields */ }
Compute the future value

Parameters

  • rate : an interest rate compounded once per period
  • nper : number of compounding periods
  • pmt : payment in each period
  • pv : present value
  • when : when payments are due WhenType. Defaults to When::End

Return:

  • fv: the value at the end of the nper periods, which is used in other modules as parameter

Example

use rfinancial::*;
let fv = FutureValue::from_tuple((0.075, 20, -2000.0, 0.0, WhenType::End));
println!("{:#?}'s fv is {:?}", fv, fv.get());

Implementations

Source

impl FutureValue

pub fn from_tuple(tup: (f64, u32, f64, f64, WhenType)) -> Self

Instantiate a FutureValue instance from a tuple of (rate, nper, pmt, pv and when) in said order

pub fn from_map(map: ParaMap) -> Result<Self>

Instantiate a FutureValue instance from a hash map with keys of (rate, nper, pmt, pv and when) in said order Since [HashMap] requires values of same type, we need to wrap into a variant of enum

pub fn get(&self) -> Result<f64>

Get the future value from an instance of FutureValue